[![codecov](https://codecov.io/gh/stefanondisponibile/theboringlibrary/branch/develop/graph/badge.svg?token=8VHJ01UKLX)](https://codecov.io/gh/stefanondisponibile/theboringlibrary)

# theboringlibrary

It does nothing.
